@@ -35,6 +35,8 @@ var RelayRecordSource = require('./RelayRecordSource');
 
 var defaultGetDataID = require('./defaultGetDataID');
 
+var defaultRequiredFieldLogger = require('./defaultRequiredFieldLogger');
+
 var generateID = require('../util/generateID');
 
 var invariant = require("fbjs/lib/invariant");
@@ -43,20 +45,26 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
   function RelayModernEnvironment(config) {
     var _this = this;
 
-    var _config$log, _config$UNSTABLE_defa, _config$UNSTABLE_DO_N, _config$scheduler, _config$isServer, _config$operationTrac;
+    var _config$log, _config$requiredField, _config$UNSTABLE_defa, _config$UNSTABLE_DO_N, _config$scheduler, _config$isServer, _config$operationTrac;
 
     this.configName = config.configName;
     var handlerProvider = config.handlerProvider ? config.handlerProvider : RelayDefaultHandlerProvider;
     this._treatMissingFieldsAsNull = config.treatMissingFieldsAsNull === true;
     var operationLoader = config.operationLoader;
+    var reactFlightPayloadDeserializer = config.reactFlightPayloadDeserializer;
 
     if (process.env.NODE_ENV !== "production") {
       if (operationLoader != null) {
         !(typeof operationLoader === 'object' && typeof operationLoader.get === 'function' && typeof operationLoader.load === 'function') ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayModernEnvironment: Expected `operationLoader` to be an object ' + 'with get() and load() functions, got `%s`.', operationLoader) : invariant(false) : void 0;
       }
+
+      if (reactFlightPayloadDeserializer != null) {
+        !(typeof reactFlightPayloadDeserializer === 'function') ? process.env.NODE_ENV !== "production" ? invariant(false, 'RelayModernEnvironment: Expected `reactFlightPayloadDeserializer` ' + ' to be a function, got `%s`.', reactFlightPayloadDeserializer) : invariant(false) : void 0;
+      }
     }
 
     this.__log = (_config$log = config.log) !== null && _config$log !== void 0 ? _config$log : emptyFunction;
+    this.requiredFieldLogger = (_config$requiredField = config.requiredFieldLogger) !== null && _config$requiredField !== void 0 ? _config$requiredField : defaultRequiredFieldLogger;
     this._defaultRenderPolicy = ((_config$UNSTABLE_defa = config.UNSTABLE_defaultRenderPolicy) !== null && _config$UNSTABLE_defa !== void 0 ? _config$UNSTABLE_defa : RelayFeatureFlags.ENABLE_PARTIAL_RENDERING_DEFAULT === true) ? 'partial' : 'full';
     this._operationLoader = operationLoader;
     this._operationExecutions = new Map();
@@ -93,6 +101,7 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
 
     this._missingFieldHandlers = config.missingFieldHandlers;
     this._operationTracker = (_config$operationTrac = config.operationTracker) !== null && _config$operationTrac !== void 0 ? _config$operationTrac : new RelayOperationTracker();
+    this._reactFlightPayloadDeserializer = reactFlightPayloadDeserializer;
   }
 
   var _proto = RelayModernEnvironment.prototype;
@@ -174,6 +183,7 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
         operationLoader: _this5._operationLoader,
         optimisticConfig: optimisticConfig,
         publishQueue: _this5._publishQueue,
+        reactFlightPayloadDeserializer: _this5._reactFlightPayloadDeserializer,
         scheduler: _this5._scheduler,
         sink: sink,
         source: source,
@@ -212,6 +222,7 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
         operationLoader: _this6._operationLoader,
         optimisticConfig: null,
         publishQueue: _this6._publishQueue,
+        reactFlightPayloadDeserializer: _this6._reactFlightPayloadDeserializer,
         scheduler: _this6._scheduler,
         sink: sink,
         source: RelayObservable.from({
@@ -300,7 +311,6 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
     var _this9 = this;
 
     var operation = _ref.operation,
-        cacheConfig = _ref.cacheConfig,
         updater = _ref.updater;
 
     var _this$__createLogObse = this.__createLogObserver(operation.request.node.params, operation.request.variables),
@@ -308,7 +318,7 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
         logRequestInfo = _this$__createLogObse[1];
 
     return RelayObservable.create(function (sink) {
-      var source = _this9._network.execute(operation.request.node.params, operation.request.variables, cacheConfig || {}, null, logRequestInfo)["do"](logObserver);
+      var source = _this9._network.execute(operation.request.node.params, operation.request.variables, operation.request.cacheConfig || {}, null, logRequestInfo)["do"](logObserver);
 
       var executor = RelayModernQueryExecutor.execute({
         operation: operation,
@@ -316,6 +326,7 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
         operationLoader: _this9._operationLoader,
         optimisticConfig: null,
         publishQueue: _this9._publishQueue,
+        reactFlightPayloadDeserializer: _this9._reactFlightPayloadDeserializer,
         scheduler: _this9._scheduler,
         sink: sink,
         source: source,
@@ -345,8 +356,7 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
   _proto.executeMutation = function executeMutation(_ref2) {
     var _this10 = this;
 
-    var cacheConfig = _ref2.cacheConfig,
-        operation = _ref2.operation,
+    var operation = _ref2.operation,
         optimisticResponse = _ref2.optimisticResponse,
         optimisticUpdater = _ref2.optimisticUpdater,
         updater = _ref2.updater,
@@ -367,7 +377,7 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
         };
       }
 
-      var source = _this10._network.execute(operation.request.node.params, operation.request.variables, _objectSpread({}, cacheConfig, {
+      var source = _this10._network.execute(operation.request.node.params, operation.request.variables, _objectSpread(_objectSpread({}, operation.request.cacheConfig), {}, {
         force: true
       }), uploadables, logRequestInfo)["do"](logObserver);
 
@@ -377,6 +387,7 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
         operationLoader: _this10._operationLoader,
         optimisticConfig: optimisticConfig,
         publishQueue: _this10._publishQueue,
+        reactFlightPayloadDeserializer: _this10._reactFlightPayloadDeserializer,
         scheduler: _this10._scheduler,
         sink: sink,
         source: source,
@@ -415,6 +426,7 @@ var RelayModernEnvironment = /*#__PURE__*/function () {
         operationTracker: _this11._operationTracker,
         optimisticConfig: null,
         publishQueue: _this11._publishQueue,
+        reactFlightPayloadDeserializer: _this11._reactFlightPayloadDeserializer,
         scheduler: _this11._scheduler,
         sink: sink,
         source: source,
